# unitorch.cli.models.beit

## BeitProcessor

!!! tip
    **`core/process/beit`** is the section for configuration of BeitProcessor.

::: unitorch.cli.models.beit.BeitProcessor

## BeitForImageClassification

!!! tip
    **`core/model/classification/beit`** is the section for configuration of BeitForImageClassification.

::: unitorch.cli.models.beit.BeitForImageClassification
